@@ -1,7 +1,7 @@
 #' Part of Speech Filtering of Token Variables
 #'
-#' `step_pos_filter` creates a *specification* of a recipe step that will filter
-#' a [`token`][tokenlist()] variable based on part of speech tags.
+#' `step_pos_filter()` creates a *specification* of a recipe step that will
+#' filter a [`token`][tokenlist()] variable based on part of speech tags.
 #'
 #' @template args-recipe
 #' @template args-dots
@@ -112,22 +112,20 @@ bake.step_pos_filter <- function(object, new_data, ...) {
   col_names <- object$columns
   check_new_data(col_names, object, new_data)
 
-  for (i in seq_along(col_names)) {
-    variable <- new_data[, col_names[i], drop = TRUE]
+  for (col_name in col_names) {
+    variable <- new_data[[col_name]]
 
     if (is.null(maybe_get_pos(variable))) {
       rlang::abort(
         glue(
-          "`{col_names[i]}` doesn't have a pos attribute. ",
+          "`{col_name}` doesn't have a pos attribute. ",
           "Make sure the tokenization step includes ",
           "part of speech tagging."
         )
       )
-    } else {
-      pos_filter_variable <- tokenlist_pos_filter(variable, object$keep_tags)
     }
 
-    new_data[, col_names[i]] <- tibble(pos_filter_variable)
+    new_data[[col_name]] <- tokenlist_pos_filter(variable, object$keep_tags)
   }
   new_data <- factor_to_text(new_data, col_names)
   new_data
@@ -150,8 +148,7 @@ tidy.step_pos_filter <- function(x, ...) {
   } else {
     term_names <- sel2char(x$terms)
     res <- tibble(
-      terms = term_names,
-      value = na_chr
+      terms = term_names
     )
   }
   res$id <- x$id
