@@ -66,65 +66,64 @@ test_that("factor input", {
   expect_equal(sum(is.na(cleaned_te$name)), 5)
 })
 
+# Infrastructure ---------------------------------------------------------------
+
 test_that("bake method errors when needed non-standard role columns are missing", {
   skip_if_not_installed("janitor")
   rec <- recipe(~name, data = smith_tr) %>%
     step_clean_levels(name) %>%
     update_role(name, new_role = "potato") %>%
     update_role_requirements(role = "potato", bake = FALSE)
-
+  
   trained <- prep(rec, training = smith_tr, verbose = FALSE)
-
+  
   expect_error(
     bake(trained, new_data = smith_tr[, -1]),
     class = "new_data_missing_column"
   )
 })
 
-test_that("printing", {
-  skip_if_not_installed("janitor")
-  rec <- rec %>% step_clean_levels(name)
-  expect_snapshot(print(rec))
-  expect_snapshot(prep(rec))
+test_that("empty printing", {
+  rec <- recipe(mpg ~ ., mtcars)
+  rec <- step_clean_levels(rec)
+  
+  expect_snapshot(rec)
+  
+  rec <- prep(rec, mtcars)
+  
+  expect_snapshot(rec)
 })
 
 test_that("empty selection prep/bake is a no-op", {
   rec1 <- recipe(mpg ~ ., mtcars)
   rec2 <- step_clean_levels(rec1)
-
+  
   rec1 <- prep(rec1, mtcars)
   rec2 <- prep(rec2, mtcars)
-
+  
   baked1 <- bake(rec1, mtcars)
   baked2 <- bake(rec2, mtcars)
-
+  
   expect_identical(baked1, baked1)
 })
 
 test_that("empty selection tidy method works", {
   rec <- recipe(mpg ~ ., mtcars)
   rec <- step_clean_levels(rec)
-
-  expect_identical(
-    tidy(rec, number = 1),
-    tibble(terms = character(), id = character())
-  )
-
+  
+  expect <- tibble(terms = character(), id = character())
+  
+  expect_identical(tidy(rec, number = 1), expect)
+  
   rec <- prep(rec, mtcars)
-
-  expect_identical(
-    tidy(rec, number = 1),
-    tibble(terms = character(), id = character())
-  )
+  
+  expect_identical(tidy(rec, number = 1), expect)
 })
 
-test_that("empty printing", {
-  rec <- recipe(mpg ~ ., mtcars)
-  rec <- step_clean_levels(rec)
-
-  expect_snapshot(rec)
-
-  rec <- prep(rec, mtcars)
-
-  expect_snapshot(rec)
-})
+test_that("printing", {
+  skip_if_not_installed("janitor")
+  rec <- rec %>% step_clean_levels(name)
+  
+  expect_snapshot(print(rec))
+  expect_snapshot(prep(rec))
+})
\ No newline at end of file
