@@ -29,7 +29,7 @@ test_that("lemmatization works", {
       c("I", "would", "not", "eat", "they", "here", "or", "there", "."),
       c("I", "would", "not", "eat", "they", "anywhere", "."),
       c("I", "would", "not", "eat", "green", "egg", "and", "ham", "."),
-      c("I", "do", "not", "like", "they", ",", "Sam", "-", "I", "-", "am", ".")
+      c("I", "do", "not", "like", "they", ",", "Sam", "-", "I", "-", "be", ".")
     )
   )
 
@@ -49,54 +49,74 @@ test_that("lemmatization errors if lemma attribute doesn't exists", {
   )
 })
 
-test_that("printing", {
+# Infrastructure ---------------------------------------------------------------
+
+test_that("bake method errors when needed non-standard role columns are missing", {
   skip_on_cran()
   skip_if_no_python_or_no_spacy()
-  rec <- recipe(~text, data = text) %>%
+
+  tokenized_test_data <- recipe(~text, data = text) %>%
     step_tokenize(all_predictors(), engine = "spacyr") %>%
-    step_lemma(all_predictors())
-
-  expect_snapshot(print(rec))
-  expect_snapshot(prep(rec))
-})
-
-test_that("empty selection prep/bake is a no-op", {
-  rec1 <- recipe(mpg ~ ., mtcars)
-  rec2 <- step_lemma(rec1)
-
-  rec1 <- prep(rec1, mtcars)
-  rec2 <- prep(rec2, mtcars)
-
-  baked1 <- bake(rec1, mtcars)
-  baked2 <- bake(rec2, mtcars)
-
-  expect_identical(baked1, baked1)
-})
-
-test_that("empty selection tidy method works", {
-  rec <- recipe(mpg ~ ., mtcars)
-  rec <- step_lemma(rec)
-
-  expect_identical(
-    tidy(rec, number = 1),
-    tibble(terms = character(), id = character())
-  )
-
-  rec <- prep(rec, mtcars)
-
-  expect_identical(
-    tidy(rec, number = 1),
-    tibble(terms = character(), id = character())
+    prep() %>%
+    bake(new_data = NULL)
+  
+  rec <- recipe(tokenized_test_data) %>%
+    step_lemma(text) %>%
+    update_role(text, new_role = "potato") %>%
+    update_role_requirements(role = "potato", bake = FALSE)
+  
+  trained <- prep(rec)
+  
+  expect_error(
+    bake(trained, new_data = tokenized_test_data[, -1]),
+    class = "new_data_missing_column"
   )
 })
 
 test_that("empty printing", {
   rec <- recipe(mpg ~ ., mtcars)
   rec <- step_lemma(rec)
-
+  
   expect_snapshot(rec)
-
+  
   rec <- prep(rec, mtcars)
-
+  
   expect_snapshot(rec)
 })
+
+test_that("empty selection prep/bake is a no-op", {
+  rec1 <- recipe(mpg ~ ., mtcars)
+  rec2 <- step_lemma(rec1)
+  
+  rec1 <- prep(rec1, mtcars)
+  rec2 <- prep(rec2, mtcars)
+  
+  baked1 <- bake(rec1, mtcars)
+  baked2 <- bake(rec2, mtcars)
+  
+  expect_identical(baked1, baked1)
+})
+
+test_that("empty selection tidy method works", {
+  rec <- recipe(mpg ~ ., mtcars)
+  rec <- step_lemma(rec)
+  
+  expect <- tibble(terms = character(), id = character())
+  
+  expect_identical(tidy(rec, number = 1), expect)
+  
+  rec <- prep(rec, mtcars)
+  
+  expect_identical(tidy(rec, number = 1), expect)
+})
+
+test_that("printing", {
+  skip_on_cran()
+  skip_if_no_python_or_no_spacy()
+  rec <- recipe(~text, data = text) %>%
+    step_tokenize(all_predictors(), engine = "spacyr") %>%
+    step_lemma(all_predictors())
+  
+  expect_snapshot(print(rec))
+  expect_snapshot(prep(rec))
+})
